using System;
using Oxide.Core;
using Oxide.Core.Libraries.Covalence;
using System.Collections.Generic;

namespace Oxide.Plugins
{
    [Info("Playercount", "M&B-Studios", "1.0.0")]
    [Description("Shows the number of players online and their names.")]
    public class Playercount : CovalencePlugin
    {
        private const string PERMISSION_PLAYERCOUNT = "playercount.use"; // Define the permission name

        private void Init()
        {
            // Register the command to show player count and names
            AddCovalenceCommand("playercount", "CmdPlayerCount");

            // Register the permission
            permission.RegisterPermission(PERMISSION_PLAYERCOUNT, this);
        }

        private void CmdPlayerCount(IPlayer player, string command, string[] args)
        {
            // Check if the player has the required permission to execute the command
            if (!player.HasPermission(PERMISSION_PLAYERCOUNT))
            {
                player.Message("You don't have permission to use this command.");
                return;
            }

            // Get a list of all connected players and explicitly convert it to a List
            List<IPlayer> allPlayers = new List<IPlayer>(players.Connected);

            // Count the number of online players
            int onlinePlayerCount = allPlayers.Count;

            // Create a list to store the names of online players
            List<string> onlinePlayerNames = new List<string>();

            // Add each player's name to the list
            foreach (var p in allPlayers)
            {
                onlinePlayerNames.Add(p.Name);
            }

            // Send the player the player count and names
            player.Message($"Online Players: {onlinePlayerCount}");
            player.Message("Player Names: " + string.Join(", ", onlinePlayerNames));
        }
    }
}
